@@ -367,7 +367,10 @@ else:
 
 def zstandard_write_block(encoder, block_bytes, compression_level):
     """Write block in "zstandard" codec."""
-    data = zstd.ZstdCompressor().compress(block_bytes)
+    if compression_level is not None:
+        data = zstd.ZstdCompressor(level=compression_level).compress(block_bytes)
+    else:
+        data = zstd.ZstdCompressor().compress(block_bytes)
     encoder.write_long(len(data))
     encoder._fo.write(data)
 
@@ -675,7 +678,7 @@ def schemaless_writer(fo, schema, record):
     Example::
 
         parsed_schema = fastavro.parse_schema(schema)
-        with open('file', 'rb') as fp:
+        with open('file', 'wb') as fp:
             fastavro.schemaless_writer(fp, parsed_schema, record)
 
     Note: The ``schemaless_writer`` can only write a single record.
